close all
% caoutchouc
E = 21e5; nu = 0.45; %nu = 0.28; 
mu= E/(2*(1+nu));
lambda = E*nu/((1+nu)*(1-2*nu));
N=7;
%  
[geodir,meshdir]=fc_vfemp1.default_directories(2);
geofile='barwith4holes';

fprintf('------------------------------------------------------\n'); 
fprintf('      2D elasticity BVP on a bar with 4 holes\n\n');
fprintf('             -div(sigma(u)) = f \n');
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [1]\n');
fprintf('       u_1 = u_2 = 0 on [1],\n');
fprintf('   * Neumann on all the others\n');
fprintf('       sigma(u).n = 0 on [2,3,4,12,14,16,18]\n');
fprintf(' with f=(0,-500)^t, lambda=%g, mu=%g\n',lambda,mu);
fprintf('------------------------------------------------------\n'); 
dim=2;

fprintf('1. Building the mesh using gmsh with %s.geo file\n',geofile);
meshfile=gmsh.buildmesh(geofile,N,'d',2,'geodir',geodir,'meshdir',meshdir);%,'force',true)
Th=siMesh(meshfile,'dim',2,'format','gmsh');
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());
fprintf('2.a Setting 2D elasticity BVP\n');
%Hop=Hoperator.StiffElas(dim,lam,mu);
gamma=lambda+2*mu;
Hop=Hoperator(dim,dim,dim);
Hop.set(1,1,Loperator(dim,dim,{gamma,[];[],mu},[],[],[])); 
Hop.set(1,2,Loperator(dim,dim,{[],lambda;mu,[]},[],[],[]));
Hop.set(2,1,Loperator(dim,dim,{[],mu;lambda,[]},[],[],[]));
Hop.set(2,2,Loperator(dim,dim,{mu,[];[],gamma},[],[],[]));
pde=PDEelt(Hop,{0,-500});
bvp=BVP(Th,pde);
bvp.setDirichlet(1,0.,1:2);
bvp.setDirichlet(3,0.,1:2);
fprintf('2.b Solving 2D elasticity BVP\n')
U=bvp.solve('split',true);

fprintf('3. Graphic representations\n');
options=fc_tools.graphics.DisplayFigures('nfig',6);
interpreter=@(x) fc_tools.graphics.interpreter(x);

figure(1)
Th.plotmesh('color',0.85*[1,1,1])
hold on,axis image,axis off
Th.plotmesh('d',1,'LineWidth',1.5,'legend',true)
set(legend(),options.legend{:})
title(interpreter(sprintf('$n_q=%d$, $n_{me}=%d$',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});

scale=50;
idx=Th.find(2); % for this mesh, only 1 elt
sTh=Th.sTh{idx}.copy();
sTh.q=sTh.q+scale*[U{1}';U{2}'];
figure(2)
Th.plotmesh()
hold on
sTh.plotmesh('color','r')
axis off, axis image
title(sprintf('Mesh displacement in red scaled by %d',scale),options.title{:});

v=sqrt(U{1}.^2+U{2}.^2);
figure(3)
Th.plot(v,'facecolor','interp','edgecolor','none')
hold on
Th.plotiso(v,'niso',15,'color','w')
set(colorbar(),options.colorbar{:})
axis image, axis off
title(interpreter(sprintf('Norm of the displacement vector $U$',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});

figure(4)
Th.plot(U{1},'facecolor','interp','edgecolor','none')
hold on
Th.plotiso(U{1},'niso',15,'color','w')
set(colorbar(),options.colorbar{:})
axis image, axis off
title(interpreter(sprintf('Horizontal displacement : $U_1$',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});

figure(5)
Th.plot(U{2},'facecolor','interp','edgecolor','none')
hold on
Th.plotiso(U{2},'niso',15,'color','w')
set(colorbar(),options.colorbar{:})
axis image, axis off
title(interpreter(sprintf('Vertical displacement : $U_2$',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});


figure(6)
Th.plotVectorField([U{1},U{2}]','colordata',v,'scale',10)
hold on
colormap('jet')
Th.plotmesh('d',1,'color','k','linewidth',2)
axis image,axis off
set(colorbar(),options.colorbar{:})
title(interpreter(sprintf('Vector displacement',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});





